@@ -33,6 +33,13 @@ from .data_table import to_data_table, to_data_frame
 
 from .autoclean import AutoClean
 
+from .encoding import (
+    EffectEncoder,
+    IdentityEncoder,
+    InteractionEncoder,
+    DatasetEncoder,
+)
+
 from .graphics_device import get_current_graphics_device
 
 from .mcmc import suggest_burn
