@@ -1,6 +1,8 @@
 #include <pybind11/pybind11.h>
 #include <pybind11/stl.h>
 
+#include <sstream>
+
 #include "Models/ModelTypes.hpp"
 #include "Models/Glm/Glm.hpp"
 #include "Models/Glm/GlmCoefs.hpp"
@@ -9,12 +11,14 @@
 #include "Models/Glm/LoglinearModel.hpp"
 #include "Models/Glm/BinomialLogitModel.hpp"
 #include "Models/Glm/PoissonRegressionModel.hpp"
+#include "Models/Glm/RegressionSlabPrior.hpp"
 #include "Models/Glm/VariableSelectionPrior.hpp"
 
 #include "Models/Glm/PosteriorSamplers/BregVsSampler.hpp"
 #include "Models/Glm/PosteriorSamplers/TRegressionSpikeSlabSampler.hpp"
 #include "Models/Glm/PosteriorSamplers/BinomialLogitSpikeSlabSampler.hpp"
 #include "Models/Glm/PosteriorSamplers/PoissonRegressionSpikeSlabSampler.hpp"
+#include "Models/Glm/PosteriorSamplers/BigAssSpikeSlabSampler.hpp"
 
 #include "cpputil/Ptr.hpp"
 
@@ -59,6 +63,33 @@ namespace BayesBoom {
              "Args:\n\n"
              "  y: Response"
              "  x: BOOM::Vector of predictors.")
+        .def("__repr__",
+             [](const RegressionData &dp) {
+               std::ostringstream out;
+               out << dp;
+               return out.str();
+             })
+        ;
+
+    py::class_<BinomialRegressionData,
+               Ptr<BinomialRegressionData>>(boom, "BinomialRegressionData")
+        .def(py::init(
+            [](double y, double n, const Vector &x) {
+              return new BinomialRegressionData(y, n, x);
+            }),
+             py::arg("y"),
+             py::arg("n"),
+             py::arg("x"),
+             "Args:\n\n"
+             "  y: Success count.  0 <= y <= n\n"
+             "  n: Trial count.  n >= 0\n"
+             "  x: Vector of predictors\n")
+        .def("__repr__",
+             [](const BinomialRegressionData &dp) {
+               std::ostringstream out;
+               out << dp;
+               return out.str();
+             })
         ;
 
     py::class_<MvRegData, Ptr<MvRegData>>(boom, "MvRegData")
@@ -90,6 +121,11 @@ namespace BayesBoom {
             "coef",
             [](const GlmModel &m) {return m.coef();},
             "The object containing the model coefficients.")
+        .def_property_readonly(
+            "Beta",
+            [](const GlmModel &m) {return m.Beta();},
+            "A BayesBoom.Vector containing the model coefficients, including "
+            "any 0's if sparse modeling is being used.")
         ;
 
     py::class_<RegSuf,
@@ -163,6 +199,94 @@ namespace BayesBoom {
              })
         ;
 
+    py::class_<RegressionSlabPrior,
+               MvnBase,
+               Ptr<RegressionSlabPrior>>(
+                   boom, "RegressionSlabPrior", py::multiple_inheritance())
+        .def(py::init(
+            [] (const SpdMatrix &xtx,
+                const Ptr<UnivParams> &sigsq_param,
+                double sample_mean,
+                double sample_size,
+                double prior_sample_size,
+                double diagonal_shrinkage) {
+              return new RegressionSlabPrior(
+                  xtx, sigsq_param, sample_size, sample_size,
+                  prior_sample_size, diagonal_shrinkage);
+            }),
+             py::arg("xtx"),
+             py::arg("sigsq_param"),
+             py::arg("sample_mean"),
+             py::arg("sample_size"),
+             py::arg("prior_sample_size"),
+             py::arg("diagonal_shrinkage"),
+             "Args:\n\n"
+             "  xtx:  The cross product matrix from the regression model.\n"
+             "  sigsq_param:  The residual variance parameter object from "
+             "the regression model.\n"
+             "  sample_mean:  The mean of the response variable.\n"
+             "  sample_size:  The number of observations in the regression "
+             "problem.\n"
+             "  prior_sample_size:  The number of observations worth of weight "
+             "to assign the prior.\n"
+             "  diagonal_shrinkage:  The xtx matrix is averaged with its own "
+             "diagonal to protect against the possibility that xtx is less "
+             "than full rank.  The diagonal_shrinkage parameter is the weight "
+             "(between 0 and 1) assigned to the diagonal in this averaging "
+             "procedure.\n" )
+        ;
+
+    py::class_<BigRegressionModel,
+               GlmModel,
+               PriorPolicy,
+               Ptr<BigRegressionModel>>(
+                   boom, "BigRegressionModel", py::multiple_inheritance())
+        .def(py::init(
+            [](uint xdim, int subordinate_model_max_dim, bool force_intercept) {
+              return new BigRegressionModel(
+                  xdim, subordinate_model_max_dim, force_intercept);
+                  }),
+             py::arg("xdim"),
+             py::arg("subordinate_model_max_dim") = 500,
+             py::arg("use_threads") = true,
+             "Args:\n\n"
+             "  xdim:  Dimension of the predictor vector.\n"
+             "  subordinate_model_max_dim:  The largest dimension of each "
+             "subordinate model (the model used to do the initial screen).\n"
+             "  use_threads:  If True then C++11 threads are used to implement"
+             " the initial screen.  If False then no threads are used.  This "
+             "argument is primarily used for debugging.")
+        .def("stream_data_for_initial_screen",
+             [](BigRegressionModel &model,
+                const RegressionData &data_point) {
+               model.stream_data_for_initial_screen(data_point);
+             },
+             py::arg("data_point"),
+             "Args:\n\n"
+             "   data_point:  A data point (of class boom.RegressionData).\n"
+             "\n"
+             "Pass the data to the subordinate models stored inside the "
+             "BigRegressionModel. The data are not stored in raw form, but "
+             "added to the subordinate models's sufficient statistics.\n")
+        .def("stream_data_for_restricted_model",
+             [](BigRegressionModel &model, const RegressionData &data_point) {
+               model.stream_data_for_restricted_model(data_point);
+             },
+             py::arg("data_point"),
+             "Args:\n\n"
+             "   data_point:  A data point (of class boom.RegressionData).\n"
+             "\n"
+             "Pass the data to the restricted model stored inside the  "
+             "BigRegressionModel. The data are not stored in raw form, but "
+             "added to the restricted models's sufficient statistics.\n")
+        .def_property_readonly(
+            "Sigsq_prm",
+            [](BigRegressionModel &m) {
+              return m.Sigsq_prm();
+            },
+            "The parameter object representing the residual variance.  boom.UnivParams")
+        ;
+
     py::class_<TRegressionModel,
                GlmModel,
                PriorPolicy,
@@ -240,6 +364,15 @@ namespace BayesBoom {
           "  include_all:  Include all the predictors initially.  If False "
           "then only the intercept starts out included.\n"
           )
+        .def("add_data",
+             [](BinomialLogitModel &model,
+                const Ptr<BinomialRegressionData> &data_point) {
+               model.add_data(data_point);
+             },
+             py::arg("data_point"),
+             "Args:\n\n"
+             "  data_point: An object of class BinomialRegressionData "
+             "containing the data for a single observation.\n")
         ;
 
     py::class_<PoissonRegressionModel,
@@ -491,6 +624,50 @@ namespace BayesBoom {
              "")
         ;
 
+    py::class_<BigAssSpikeSlabSampler,
+               PosteriorSampler,
+               Ptr<BigAssSpikeSlabSampler>>(
+                       boom, "BigAssSpikeSlabSampler")
+        .def(py::init([](BigRegressionModel *model,
+                         VariableSelectionPrior *global_spike,
+                         RegressionSlabPrior *slab_prototype,
+                         GammaModelBase *residual_precision_prior,
+                         RNG &seeding_rng){
+                        return new BigAssSpikeSlabSampler(
+                            model, global_spike, slab_prototype, residual_precision_prior, seeding_rng);
+                      }),
+             py::arg("model"),
+             py::arg("global_spike"),
+             py::arg("slab_prototype"),
+             py::arg("residual_precision_prior"),
+             py::arg("seeding_rng_") = BOOM::GlobalRng::rng,
+             "Args:\n\n"
+             "  model:  The boom.BigRegressionModel to be sampled.\n"
+             "  global_spike:  A boom.VariableSelectionPrior describing which variables"
+             " are included in the model.\n"
+             "  slab_prototype: A boom.RegressionSlabPrior prior for the conditional distribution of "
+             "the regression coefficients given inclusion.\n"
+             "  seeding_rng:  The random number generator used to set the seed "
+             "of the RNG owned by this sampler.\n"
+             )
+        .def("initial_screen",
+             [](BigAssSpikeSlabSampler &sampler, int niter, double threshold,
+                bool use_threads) {
+               sampler.initial_screen(niter, threshold, use_threads);
+             },
+             py::arg("niter"),
+             py::arg("threshold"),
+             py::arg("use_threads") = true,
+             "Args:\n\n"
+             "  niter:  The number of MCMC iterations to use in the initial "
+             "screen.\n"
+             "  threshold: The variables whose 'marginal inclusion probabilities'"
+             "exceed 'threshold' become candidates in the next round.\n"
+             "  use_threads: If 'True' then C++11 threads will be used to run "
+             "the MCMC algorithms for the subordinate models.  If 'False' then "
+             "the code path for doing the MCMC will not use threads.\n")
+        .def("draw", [](BigAssSpikeSlabSampler &sampler) {sampler.draw();})
+        ;
 
   }  // module definition
 
